## dbt-snowflake 1.11.1 - January 08, 2026

### Fixes

- Add override of diff_column_data_types to preserve collation while altering column ([#1258](https://github.com/dbt-labs/dbt-adapters/issues/1258))

### Dependencies

- Update dbt-adapters dep to 1.22.3 ([#1528](https://github.com/dbt-labs/dbt-adapters/pull/1528))
